@@ -19,9 +19,15 @@
 #ifndef _LIBBRIDGE_H
 #define _LIBBRIDGE_H
 
-#include <net/if.h>
+#include <sys/socket.h>
+#include <linux/if.h>
 #include <linux/if_bridge.h>
 
+/* defined in net/if.h but that conflicts with linux/if.h... */
+extern unsigned int if_nametoindex (const char *__ifname);
+extern char *if_indextoname (unsigned int __ifindex, char *__ifname);
+
+
 struct bridge_id
 {
 	unsigned char prio[2];
